% Basic RBC Model
% + Variable capital utilization
% gauthier[at]vermandel.fr
% vermandel 2013

close all;
%format long

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------

var y c k ku u i h w r z a g;
varexo e_a e_g;

parameters	beta alpha delta sigmaC sigmaL gy
			rho_a rho_g
			R Y C Z I Z2 K
			;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------

% Loading calibration
@#include "calibration.mod"

%----------------------------------------------------------------
% 3. Model (the number refers to the equation in the paper)
%----------------------------------------------------------------
model(linear);
    %% Household
	% Euler
	sigmaC*(c(+1)-c)=r;
	% hours supply
	w = (1/sigmaL)*h + sigmaC*c;

	%% Capital supply
	% No arbitrage Bonds-Capital
	R*r = Z*z(+1);
	% Capital law of motion
	delta*i = k-(1-delta)*k(-1);
	% utilization cost
	z = Z2*u;
	% utilized capital
	ku = u + k(-1);

    % Intermediary firms
	% Production function
	y = a + alpha*ku + (1-alpha)*h;
	% Inputs Cost minimization
	z = y - ku;
	w + h = z + ku;
    % Resources constraint
	Y*y = C*c + I*i + gy*Y*g + Z*K*u;
	
    % Exogenous shocks
	a = rho_a*a(-1) + e_a;
	g = rho_g*g(-1) + e_g;
end;

%----------------------------------------------------------------
% 4. Computation
%----------------------------------------------------------------
check;
steady;


stoch_simul(order = 1,irf=30) y c k i w h r;